Module combined_generator

Module combined_generator 

Combined trait for generators that can both generate code and write files

Traits

CombinedGenerator
Combined trait for generators that can both generate code and write files