pub struct ObjectSchema {Show 33 fields
pub all_of: Vec<ObjectOrReference<ObjectSchema>>,
pub any_of: Vec<ObjectOrReference<ObjectSchema>>,
pub one_of: Vec<ObjectOrReference<ObjectSchema>>,
pub items: Option<Box<Schema>>,
pub properties: BTreeMap<String, ObjectOrReference<ObjectSchema>>,
pub additional_properties: Option<AdditionalProperties>,
pub schema_type: Option<String>,
pub enum_values: Vec<Value>,
pub multiple_of: Option<Number>,
pub maximum: Option<Number>,
pub exclusive_maximum: Option<Number>,
pub minimum: Option<Number>,
pub exclusive_minimum: Option<Number>,
pub max_length: Option<u64>,
pub min_length: Option<u64>,
pub pattern: Option<String>,
pub max_items: Option<u64>,
pub min_items: Option<u64>,
pub unique_items: Option<bool>,
pub max_properties: Option<u64>,
pub min_properties: Option<u64>,
pub required: Vec<String>,
pub format: Option<String>,
pub title: Option<String>,
pub description: Option<String>,
pub default: Option<Value>,
pub deprecated: Option<bool>,
pub nullable: Option<bool>,
pub read_only: Option<bool>,
pub write_only: Option<bool>,
pub discriminator: Option<Discriminator>,
pub example: Option<Value>,
pub extensions: BTreeMap<String, Value>,
}Expand description
A schema object allows the definition of input and output data types.
OAS 3.0 uses a single type string and optional nullable boolean.
Fields
all_of: Vec<ObjectOrReference<ObjectSchema>>any_of: Vec<ObjectOrReference<ObjectSchema>>one_of: Vec<ObjectOrReference<ObjectSchema>>items: Option<Box<Schema>>properties: BTreeMap<String, ObjectOrReference<ObjectSchema>>additional_properties: Option<AdditionalProperties>schema_type: Option<String>OAS 3.0: type is a single string (e.g. “string”, “integer”, “object”).
enum_values: Vec<Value>multiple_of: Option<Number>maximum: Option<Number>exclusive_maximum: Option<Number>minimum: Option<Number>exclusive_minimum: Option<Number>max_length: Option<u64>min_length: Option<u64>pattern: Option<String>max_items: Option<u64>min_items: Option<u64>unique_items: Option<bool>max_properties: Option<u64>min_properties: Option<u64>required: Vec<String>format: Option<String>title: Option<String>description: Option<String>default: Option<Value>deprecated: Option<bool>nullable: Option<bool>read_only: Option<bool>write_only: Option<bool>discriminator: Option<Discriminator>example: Option<Value>extensions: BTreeMap<String, Value>Implementations
Sourceimpl ObjectSchema
impl ObjectSchema
Sourcepub fn is_nullable(&self) -> Option<bool>
pub fn is_nullable(&self) -> Option<bool>
Returns true if this schema allows null (OAS 3.0: nullable: true).