Combined trait for generators that can both generate code and write files
Traits
- Combined
Generator - Combined trait for generators that can both generate code and write files
Combined trait for generators that can both generate code and write files